@@ -35,9 +35,16 @@ def load_jupyter_server_extension(nbapp):
     resuseconfig = ResourceUseDisplay(parent=nbapp)
     nbapp.web_app.settings["nbresuse_display_config"] = resuseconfig
     base_url = nbapp.web_app.settings["base_url"]
+
+    if not resuseconfig.disable_legacy_endpoint:
+        nbapp.web_app.add_handlers(
+            ".*", [(url_path_join(base_url, "/metrics"), ApiHandler)]
+        )
+
     nbapp.web_app.add_handlers(
-        ".*", [(url_path_join(base_url, "/metrics"), ApiHandler)]
+        ".*", [(url_path_join(base_url, "/api/metrics/v1"), ApiHandler)]
     )
+
     callback = ioloop.PeriodicCallback(
         PrometheusHandler(PSUtilMetricsLoader(nbapp)), 1000
     )
